{#
    ubuntu/layout.html
    ~~~~~~~~~~~~~~~~~

    Ubuntu layout template for Sphinx themes based on default Sphinx template.
    :copyright: 2010-2015, Ubuntu Developers <ubuntu-devel-discuss@lists.ubuntu.com>
    :copyright: Copyright 2007-2010 by the Sphinx team, see AUTHORS.
    :license: BSD, see LICENSE for details.
#}
{%- block doctype -%}
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
  "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
{%- endblock %}
{%- set reldelim1 = reldelim1 is not defined and ' &raquo;' or reldelim1 %}
{%- set reldelim2 = reldelim2 is not defined and ' |' or reldelim2 %}
{%- set render_sidebar = (not embedded) and (not theme_nosidebar|tobool) and
                         (sidebars != []) %}
{%- set url_root = pathto('', 1) %}
{%- if url_root == '#' %}{% set url_root = '' %}{% endif %}

{%- macro relbar() %}
<div class="header-content">
    <div class="clearfix">
  <div class="header-navigation-secondary">
    <div>
          <nav role="navigation">
            <ul class="clearfix">
        {%- for rellink in rellinks %}
	        <li class="page_item"><a {% if loop.first %}style="margin-right: 10px"{% endif %} 
	        href="{{ pathto(rellink[0]) }}" title="{{ rellink[1]|striptags|e }}"
	        {{ accesskey(rellink[2]) }}>{{ rellink[3] }}</a></li>
        {%- endfor %}
        {%- block rootrellink %}
        <li class="page_item"><a class="sub-nav-item" href="{{ pathto(master_doc) }}">{{ shorttitle|e }} {{ reldelim1 }}</a></li>
        {%- endblock %}
        {%- for parent in parents %}
          <li class="page_item"><a class="sub-nav-item" href="{{ parent.link|e }}" {% if loop.last %}{{ accesskey("U") }}{% endif %}>{{ parent.title }} {{ reldelim1 }}</a></li>
        {%- endfor %}
        {%- block relbaritems %} {% endblock %}
      </ul>
    </nav>
  </div>
</div>
</div>
</div>
{%- endmacro %}

{%- macro sidebar() %}
      {%- if render_sidebar %}
      {%- include "sidebar.html" %}
      {%- endif %}
{%- endmacro %}

<html xmlns="http://www.w3.org/1999/xhtml">
  <head>
    <meta http-equiv="Content-Type" content="text/html; charset={{ encoding }}" />
    {{ metatags }}
    {%- if not embedded and docstitle %}
      {%- set titlesuffix = " &mdash; "|safe + docstitle|e %}
    {%- else %}
      {%- set titlesuffix = "" %}
    {%- endif %}
    {%- block htmltitle %}
    <title>{{ title|striptags|e }}{{ titlesuffix }}</title>
    {%- endblock %}
    <link rel="shortcut icon" href="{{ pathto('_static/images/favicon.ico', 1) }}" type="image/x-icon" />
    <link rel="stylesheet" href="{{ pathto('_static/reset.css', 1) }}" type="text/css" />
    <link rel="stylesheet" href="{{ pathto('_static/960.css', 1) }}" type="text/css" />
    <link rel="stylesheet" href="{{ pathto('_static/base.css', 1) }}" type="text/css" />
    <link rel="stylesheet" href="{{ pathto('_static/home.css', 1) }}" type="text/css" />
    <link rel="stylesheet" href="{{ pathto('_static/pygments.css', 1) }}" type="text/css" />
    <link rel="stylesheet" href="{{ pathto('_static/guide.css', 1) }}" type="text/css" />
    {%- for cssfile in css_files %}
    <link rel="stylesheet" href="{{ pathto(cssfile, 1) }}" type="text/css" />
    {%- endfor %}
    {%- if not embedded %}
    <script type="text/javascript">
      var DOCUMENTATION_OPTIONS = {
        URL_ROOT:    '{{ url_root }}',
        VERSION:     '{{ release|e }}',
        COLLAPSE_INDEX: false,
        FILE_SUFFIX: '{{ '' if no_search_suffix else file_suffix }}',
        HAS_SOURCE:  {{ has_source|lower }}
      };
    </script>
    {%- for scriptfile in script_files %}
    <script type="text/javascript" src="{{ pathto(scriptfile, 1) }}"></script>
    {%- endfor %}
    {# <script type="text/javascript" src="{{ pathto('_static/jquery.js', 1) }}"></script> #}
    <script type="text/javascript" src="{{ pathto('_static/main.js', 1) }}"></script>
    {%- if use_opensearch %}
    <link rel="search" type="application/opensearchdescription+xml"
          title="{% trans docstitle=docstitle|e %}Search within {{ docstitle }}{% endtrans %}"
          href="{{ pathto('_static/opensearch.xml', 1) }}"/>
    {%- endif %}
    {%- if favicon %}
    <link rel="shortcut icon" href="{{ pathto('_static/' + favicon, 1) }}"/>
    {%- endif %}
    {%- endif %}
{%- block linktags %}
    {%- if hasdoc('about') %}
    <link rel="author" title="{{ _('About these documents') }}" href="{{ pathto('about') }}" />
    {%- endif %}
    {%- if hasdoc('genindex') %}
    <link rel="index" title="{{ _('Index') }}" href="{{ pathto('genindex') }}" />
    {%- endif %}
    {%- if hasdoc('search') %}
    <link rel="search" title="{{ _('Search') }}" href="{{ pathto('search') }}" />
    {%- endif %}
    {%- if hasdoc('copyright') %}
    <link rel="copyright" title="{{ _('Copyright') }}" href="{{ pathto('copyright') }}" />
    {%- endif %}
    <link rel="top" title="{{ docstitle|e }}" href="{{ pathto('index') }}" />
    {%- if parents %}
    <link rel="up" title="{{ parents[-1].title|striptags|e }}" href="{{ parents[-1].link|e }}" />
    {%- endif %}
    {%- if next %}
    <link rel="next" title="{{ next.title|striptags|e }}" href="{{ next.link|e }}" />
    {%- endif %}
    {%- if prev %}
    <link rel="prev" title="{{ prev.title|striptags|e }}" href="{{ prev.link|e }}" />
    {%- endif %}
{%- endblock %}
{%- block extrahead %} {% endblock %}
  </head>
  <body class="home">
  <a name="top"></a>

<div class="header-navigation">
    <div>
      <nav role="navigation">
        <ul>
          <li class="page_item current_page_item"><a title="{{ _('Contents') }}" href="index.html">{{ _('Contents') }}</a>
          <li>
            <form id="form-search" method="get" action="search.html">
              <fieldset>
                <input id="input-search" type="text" name="q" value="Search" />
              </fieldset>
            </form>
          </li>
        </ul>
      </nav>
      <a class="logo-ubuntu" href="http://packaging.ubuntu.com/">
        <img src="{{ pathto('_static/images/logo-ubuntu.png', 1) }}" width="119" height="27" alt="Ubuntu logo" />
      </a>
      <a href="http://packaging.ubuntu.com/"><h2>Packaging Guide</h2></a>
    </div>
  </div>

{%- block relbar1 %}{{ relbar() }}{% endblock %}

{%- block header %}{% endblock %}

{%- block content %}
  
<div id="content" class="body container_12">
  <div class="grid_12">

{%- block sidebar1 %} {# possible location for sidebar #} {% endblock %}

     <!--<section id="main-section">-->
  {%- block document %}
      {%- if render_sidebar %}
      {%- endif %}

    <div class="grid_9 alpha">
		
    {% block body %} {% endblock %}
	<div class="divide"></div>

          </div>

      {%- block sidebar2 %}{{ sidebar() }}{% endblock %}            
      {%- if render_sidebar %}
      {%- endif %}
  {%- endblock %}
    <!--</section>-->
  </div>
</div>
{%- endblock %}

{%- block footer %}
<div class="shadow"></div>
<footer>
  <div>
    {%- if version %}
      {% trans version=version|e %}Version: {{ version }}.{% endtrans %}
    {%- endif %}
    {%- if last_updated %}
      {% trans last_updated=last_updated|e %}Last updated on {{ last_updated }}.{% endtrans %}
    {%- endif %}
    <a href="https://bugs.launchpad.net/ubuntu-packaging-guide">Report bugs</a> or 
    <a href="https://code.launchpad.net/~ubuntu-packaging-guide-team/ubuntu-packaging-guide/trunk">grab the source code</a> from Launchpad.
    {%- if show_sphinx %}
      {% trans sphinx_version=sphinx_version|e %}Created using <a href="http://sphinx-doc.org/">Sphinx</a> {{ sphinx_version }}.{% endtrans %}
    {%- endif %}
    {%- if show_copyright %}
      <br />
      {%- if hasdoc('copyright') %}
        {% trans path=pathto('copyright'), copyright=copyright|e %}&copy; <a href="{{ path }}">Copyright</a> {{ copyright }}.{% endtrans %}
      {%- else %}
        {% trans copyright=copyright|e %}&copy; Copyright {{ copyright }}.{% endtrans %}
        <a rel="license" href="http://creativecommons.org/licenses/by-sa/3.0/">
        Creative Commons Attribution-ShareAlike 3.0 Unported License</a>.
        <a rel="license" href="http://creativecommons.org/licenses/by-sa/3.0/">
        <img alt="Creative Commons License" style="border-width:0" 
        src="{{ pathto('_static/images/cc-by-sa.png', 1) }}" /></a>
      {%- endif %}
    {%- endif %}
    <br />
    <a href="http://people.ubuntu.com/~mitya57/ubuntu-packaging-guide-readme.html#translating">Help translate</a> or
    <a href="{{ pathto('_static/translators.html', 1) }}">view the list of translators</a>.

  </div>
</footer>
{%- endblock %}
  </body>
</html>
