/* CSS style bits for Ubuntu developer guide */
/* Author: Dmitry Shachnev <mitya57@ubuntu.com>, 2012-2013 */

.section li, ul.search li {
    list-style-type: disc;
    margin-left: 25px;
    margin-bottom: 5px;
}

.section ul, ul.search {
    margin-top: 5px;
    margin-bottom: 10px;
}

.section h3 {
    font-weight: bold;
}

.admonition {
    padding-top: 5px;
    padding-left: 10px;
    padding-right: 5px;
    margin-bottom: 10px;
    border: 1px solid #da8;
    background-color: #ffc;
    border-radius: 3px;
}

.admonition-title {
    font-weight: bold;
    font-size: 110%;
}

.highlighted {
    background-color: #deb;
}

ul.search li a {
    font-weight: bold;
    font-size: 120%;
}

#search-results h2 {
    margin-top: 20px;
}

.context {
    margin-left: 30px;
}

th.field-name {
    font-weight: bold;
}

table.field-list {
    margin-bottom: 10px;
}

table.field-list td, table.field-list th {
    padding: 2px;
}
